@@ -457,10 +457,17 @@ def get_connection():
 
 
 def close():
+    global _DB_CTX
     global _POOLED
+
     if _POOLED:
         from .pooling import close_pool
         close_pool()
+        _POOLED = False
+
+    if _DB_CTX is not None:
+        _DB_CTX.release()
+        _DB_CTX = None
 
 
 @with_connection
