@@ -9,7 +9,7 @@ class Loader:
         self.data = data
         self.description = description
 
-    def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
         Save as csv
         :param file_name
@@ -26,7 +26,7 @@ class Loader:
 
             writer.writerows(self.data)
 
-    def df(self):
+    def to_df(self):
         """
         transform to DataFrame of pandas.
         :return DataFrame of pandas
@@ -38,7 +38,7 @@ class Loader:
 
         return pd.DataFrame(data=self.data)
 
-    def json(self, file_name: str, encoding='utf-8'):
+    def to_json(self, file_name: str, encoding='utf-8'):
         """
         Save as json
         :param file_name
