@@ -54,23 +54,23 @@ class Param:
         """
         return self.sql_exec.query_one(*self.args, **self.kwargs)
 
-    def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
-        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).csv('test.csv')
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).to_csv('test.csv')
         """
-        self.sql_exec.load(*self.args, **self.kwargs).csv(file_name, delimiter, header, encoding)
+        self.sql_exec.load(*self.args, **self.kwargs).to_csv(file_name, delimiter, header, encoding)
 
-    def df(self):
+    def to_df(self):
         """
-        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).df()
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).to_df()
         """
-        return self.sql_exec.load(*self.args, **self.kwargs).df()
+        return self.sql_exec.load(*self.args, **self.kwargs).to_df()
 
-    def json(self, file_name: str, encoding='utf-8'):
+    def to_json(self, file_name: str, encoding='utf-8'):
         """
-        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).json('test.json')
+        sqlexec.sql('SELECT * FROM person WHERE name=? and age=?').param('张三', 18).to_json('test.json')
         """
-        self.sql_exec.load(*self.args, **self.kwargs).json(file_name, encoding)
+        self.sql_exec.load(*self.args, **self.kwargs).to_json(file_name, encoding)
 
 
 class SqlExec:
