@@ -144,23 +144,23 @@ class ColumnWhereExec:
         """
         return self.where_exec.query_one(*self.columns)
 
-    def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
         sqlexec.table('person').columns('name', 'age').where(name__eq='李四').csv('test.csv')
         """
-        self.where_exec.load(*self.columns).csv(file_name, delimiter, header, encoding)
+        self.where_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
 
-    def df(self):
+    def to_df(self):
         """
         sqlexec.table('person').columns('name', 'age').where(name__eq='李四').df()
         """
-        return self.where_exec.load(*self.columns).df()
+        return self.where_exec.load(*self.columns).to_df()
 
-    def json(self, file_name: str, encoding='utf-8'):
+    def to_json(self, file_name: str, encoding='utf-8'):
         """
         sqlexec.table('person').columns('name', 'age').where(name__eq='李四').json('test.json')
         """
-        self.where_exec.load(*self.columns).json(file_name, encoding)
+        self.where_exec.load(*self.columns).to_json(file_name, encoding)
 
 
 class ColumnExec:
@@ -191,6 +191,12 @@ class ColumnExec:
         sql = sql_support.insert_sql(self.table_exec.table.strip(), self.columns)
         return exec.batch_execute(sql, *args)
 
+    def get(self):
+        """
+        sqlexec.table('person').columns('count(1)').get()
+        """
+        return self.table_exec.get(*self.columns)
+
     def select(self):
         """
         sqlexec.table('person').columns('name', 'age').select()
@@ -215,23 +221,23 @@ class ColumnExec:
         """
         return self.table_exec.query_one(*self.columns)
 
-    def csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
+    def to_csv(self, file_name: str, delimiter=',', header=True, encoding='utf-8'):
         """
-        sqlexec.table('person').columns('name', 'age').csv('test.csv')
+        sqlexec.table('person').columns('name', 'age').to_csv('test.csv')
         """
-        self.table_exec.load(*self.columns).csv(file_name, delimiter, header, encoding)
+        self.table_exec.load(*self.columns).to_csv(file_name, delimiter, header, encoding)
 
-    def df(self):
+    def to_df(self):
         """
-        sqlexec.table('person').columns('name', 'age').df()
+        sqlexec.table('person').columns('name', 'age').to_df()
         """
-        return self.table_exec.load(*self.columns).df()
+        return self.table_exec.load(*self.columns).to_df()
 
-    def json(self, file_name: str, encoding='utf-8'):
+    def to_json(self, file_name: str, encoding='utf-8'):
         """
-        sqlexec.table('person').columns('name', 'age').json('test.json')
+        sqlexec.table('person').columns('name', 'age').to_json('test.json')
         """
-        self.table_exec.load(*self.columns).json(file_name, encoding)
+        self.table_exec.load(*self.columns).to_json(file_name, encoding)
 
     def where(self, **kwargs) -> ColumnWhereExec:
         return ColumnWhereExec(self.table_exec.where(**kwargs), *self.columns)
@@ -261,6 +267,13 @@ class TableExec:
         """
         return exec.save(select_key, self.table, **kwargs)
 
+    def batch_insert(self, *args):
+        """
+        Execute sql return effect rowcount
+        :param args: [{'name': '张三', 'age': 20}, {'name': '李四', 'age': 28}]
+        """
+        return exec.batch_insert(self.table, *args)
+
     def get(self, column: str):
         """
         Execute select SQL and expected one int and only one int result, SQL contain 'limit'.
@@ -305,13 +318,6 @@ class TableExec:
         sql = get_select_sql(self.table, '', LIMIT_1, *columns)
         return exec.do_query_one(sql, LIMIT_1)
 
-    def batch_insert(self, *args):
-        """
-        Execute sql return effect rowcount
-        :param args: [{'name': '张三', 'age': 20}, {'name': '李四', 'age': 28}]
-        """
-        return exec.batch_insert(self.table, *args)
-
     def load(self, *columns) -> Loader:
         """
         sqlexec.table('person').load('name', 'age')
@@ -427,4 +433,4 @@ def get_where_arg_limit(**kwargs):
                     args.append(arg)
         where = 'WHERE {}'.format(' and '.join(conditions))
 
-    return where, args, limit
\ No newline at end of file
+    return where, args, limit
